@@ -1,10 +1,10 @@
-from sympy.external import import_module
+import os
 from spb.defaults import cfg
 from spb.backends.base_backend import Plot
 from spb.backends.utils import compute_streamtubes
 from spb.utils import get_vertices_indices
+from sympy.external import import_module
 import warnings
-import os
 
 
 class K3DBackend(Plot):
@@ -13,46 +13,43 @@ class K3DBackend(Plot):
     Parameters
     ==========
 
-    line_kw : dict, optional
-        A dictionary of keywords/values which is passed to K3D's line
-        functions to customize the appearance. Default to:
-        ``line_kw = dict(width=0.1, shader="mesh")``.
-        Set `use_cm=False` to switch to a solid color.
+    rendering_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's plot
+        functions to customize the appearance of lines, surfaces, images,
+        contours, quivers, streamlines...
+        To learn more about customization:
 
-    quiver_kw : dict, optional
-        A dictionary to customize the apppearance of quivers. Default to:
-        ``quiver_kw = dict(scale = 1, pivot = "mid")``. The keys to this
-        dictionary are:
+        * Default options for line plots:
+          ``dict(width=0.1, shader="mesh")``.
+          Set ``use_cm=False`` to switch to a solid color.
 
-        * ``scale``: a float number acting as a scale multiplier.
-        * ``pivot``: indicates the part of the arrow that is anchored to the
-          X, Y, Z grid. It can be ``"tail", "mid", "middle", "head"``.
-        * ``color``: set a solid color by specifying an integer color. If this
-          key is not provided, a default color or colormap is used, depenging
-          on the value of ``use_cm``.
+        * Default options for quiver plots:
+          ``dict(scale = 1, pivot = "mid")``. The keys to this
+          dictionary are:
 
-        Set ``use_cm=False`` to switch to a default solid color.
+          - ``scale``: a float number acting as a scale multiplier.
+          - ``pivot``: indicates the part of the arrow that is anchored to the
+            X, Y, Z grid. It can be ``"tail", "mid", "middle", "head"``.
+          - ``color``: set a solid color by specifying an integer color. If this
+            key is not provided, a default color or colormap is used, depenging
+            on the value of ``use_cm``.
+
+          Set ``use_cm=False`` to switch to a default solid color.
+
+        * Default options for streamline plots:
+          ``dict( width=0.1, shader='mesh' )``.
+          Refer to k3d.line for more options.
+          Set ``use_cm=False`` to switch to a solid color.
+
+        * To customize surface plots, refers to:
+
+          - k3d.mesh function for 3D surface and parametric surface plots.
+          - k3d.marching_cubes function for 3D implicit plots.
 
     show_label : boolean, optional
         Show/hide labels of the expressions. Default to False (labels not
         visible).
 
-    stream_kw : dict, optional
-        A dictionary to customize the apppearance of streamlines.
-        Default to:
-        ``stream_kw = dict( width=0.1, shader='mesh' )``.
-        Refer to k3d.line for more options.
-        Set `use_cm=False` to switch to a solid color.
-
-    surface_kw : dict, optional
-        A dictionary of keywords/values to to customize the appearance which
-        is passed to:
-
-        - k3d.mesh function for 3D surface and parametric surface plots.
-          Refer to k3d.meshfor more options.
-        - k3d.marching_cubes function for 3D implicit plots. Refer to
-          k3d.marching_cubes for more options.
-
     use_cm : boolean, optional
         If True, apply a color map to the meshes/surface. If False, solid
         colors will be used instead. Default to True.
@@ -236,13 +233,13 @@ class K3DBackend(Plot):
                 a = dict(
                     width=0.1,
                     name=self._get_series_label(s, "%s") if self._show_label else None,
-                    color=self._convert_to_int(next(self._cl)),
+                    color=self._convert_to_int(next(self._cl)) if s.line_color is None else s.line_color,
                     shader="mesh",
                 )
                 if s.use_cm:
                     a["attribute"] = (param.astype(np.float32),)
                     a["color_map"] = next(self._cm)
-                    a["color_range"] = [s.start, s.end]
+                    a["color_range"] = [param.min(), param.max()]
                 kw = merge({}, a, s.rendering_kw)
                 line = self.k3d.line(vertices, **kw)
                 self._fig += line
@@ -252,7 +249,7 @@ class K3DBackend(Plot):
                     x, y, z, u, v = s.get_data()
                     vertices, indices = get_vertices_indices(x, y, z)
                     vertices = vertices.astype(np.float32)
-                    attribute = s.color_func(vertices[:, 0], vertices[:, 1], vertices[:, 2], u.flatten().astype(np.float32), v.flatten().astype(np.float32))
+                    attribute = s.eval_color_func(vertices[:, 0], vertices[:, 1], vertices[:, 2], u.flatten().astype(np.float32), v.flatten().astype(np.float32))
                 else:
                     x, y, z = s.get_data()
                     x = x.flatten()
@@ -260,7 +257,7 @@ class K3DBackend(Plot):
                     z = z.flatten()
                     vertices = np.vstack([x, y, z]).T.astype(np.float32)
                     indices = Triangulation(x, y).triangles.astype(np.uint32)
-                    attribute = s.color_func(vertices[:, 0], vertices[:, 1], vertices[:, 2])
+                    attribute = s.eval_color_func(vertices[:, 0], vertices[:, 1], vertices[:, 2])
 
                 self._high_aspect_ratio(x, y, z)
                 a = dict(
@@ -268,7 +265,7 @@ class K3DBackend(Plot):
                     side="double",
                     flat_shading=False,
                     wireframe=False,
-                    color=self._convert_to_int(next(self._cl)),
+                    color=self._convert_to_int(next(self._cl)) if s.surface_color is None else s.surface_color,
                 )
                 if s.use_cm:
                     a["color_map"] = next(self._cm)
@@ -493,11 +490,11 @@ class K3DBackend(Plot):
                     if s.is_parametric:
                         x, y, z, u, v = s.get_data()
                         x, y, z, u, v = [t.flatten().astype(np.float32) for t in [x, y, z, u, v]]
-                        attribute = s.color_func(x, y, z, u, v)
+                        attribute = s.eval_color_func(x, y, z, u, v)
                     else:
                         x, y, z = s.get_data()
                         x, y, z = [t.flatten().astype(np.float32) for t in [x, y, z]]
-                        attribute = s.color_func(x, y, z)
+                        attribute = s.eval_color_func(x, y, z)
 
                     vertices = np.vstack([x, y, z]).astype(np.float32)
                     self._fig.objects[i].vertices = vertices.T
