@@ -268,9 +268,9 @@ class PanelLayout:
                 This functionality is not yet fully implemented, please don't
                 use it.
 
-            pane_kw : str, optional
-                This functionality is not yet fully implemented, please don't
-                use it.
+            pane_kw : dict, optional
+                A dictionary of keyword arguments that are going to be passed
+                to the pane containing the chart.
         """
         # NOTE: More often than not, the numerical evaluation is going to be
         # resource-intensive. By default, panel's sliders will force a
@@ -346,7 +346,9 @@ class PanelLayout:
             # activate ipympl interactive frame, as well as setting a lower
             # dpi resolution of the matplotlib image
             default_kw["dpi"] = 96
-            default_kw["interactive"] = True
+            # NOTE: the following must be set to False in order for the
+            # example outputs to become visible on Sphinx.
+            default_kw["interactive"] = False
 
         merge = self._backend.merge
         kw = merge({}, default_kw, self._pane_kw)
@@ -771,7 +773,8 @@ class InteractivePlot(DynamicParam, PanelLayout):
 
 
 def iplot(*args, show=True, **kwargs):
-    """Create interactive-widget plots of symbolic expressions.
+    """Create an interactive application containing widgets and charts in order
+    to study symbolic expressions.
 
     Note that this function is already integrated with many of the usual
     plotting functions, hence it is recommended to use those instead of
@@ -886,6 +889,20 @@ def iplot(*args, show=True, **kwargs):
         served on a new browser window. Refer to ``servable`` to learn more.
         Default to an empty string.
 
+    pane_kw : dict, optional
+        A dictionary of keyword/values which is passed to the pane containing
+        the chart in order to further customize the output (read the Notes
+        section to understand how the interactive plot is built).
+        The following web pages shows the available options:
+
+        * Refer to [#fn2]_ for ``MatplotlibBackend``. Two interesting options
+          are:
+
+          * ``interactive``: wheter to activate the ipympl interactive backend.
+          * ``dpi``: set the dots per inch of the output png. Default to 96.
+
+        * Refer to [#fn3]_ for ``PlotlyBackend``.
+
     rendering_kw : dict or list of dicts, optional
         A dictionary of keywords/values which is passed to the backend's
         function to customize the appearance of lines, surfaces, etc.
@@ -1194,17 +1211,25 @@ def iplot(*args, show=True, **kwargs):
        process loading the interactive plot on the browser.
        However, ``K3DBackend`` is not supported in this mode of operation.
 
-    2. Some examples use an instance of ``PrintfTickFormatter`` to format the
+    2. The interactive application generated by ``iplot`` consists of two main
+       containers:
+
+       * a pane containing the widgets.
+       * a pane containing the chart. We can further customize this container
+         by setting the ``pane_kw`` dictionary. Please, read its documentation
+         to understand the availabel options.
+
+    3. Some examples use an instance of ``PrintfTickFormatter`` to format the
        value shown by a slider. This class is exposed by Bokeh, but can be
        used by ``iplot`` with any backend. Refer to [#fn1]_ for more
        information about tick formatting.
 
-    3. It has been observed that Dark Reader (or other night-mode-enabling
+    4. It has been observed that Dark Reader (or other night-mode-enabling
        browser extensions) might interfere with the correct behaviour of
        the output of  ``iplot``. Please, consider adding ``localhost`` to the
        exclusion list of such browser extensions.
 
-    4. Say we are creating two different interactive plots and capturing
+    5. Say we are creating two different interactive plots and capturing
        their output on two variables, using ``show=False``. For example,
        ``p1 = iplot(..., show=False)`` and ``p2 = iplot(..., show=False)``.
        Then, running ``p1.show()`` on the screen will result in an error.
@@ -1212,24 +1237,24 @@ def iplot(*args, show=True, **kwargs):
        parameters are class attributes that gets deleted each time a new
        instance is created.
 
-    5. ``MatplotlibBackend`` can be used, but the resulting figure is just a
+    6. ``MatplotlibBackend`` can be used, but the resulting figure is just a
        PNG image without any interactive frame. Thus, data exploration is not
        great. Therefore, the use of ``PlotlyBackend`` or ``BokehBackend`` is
        encouraged.
 
-    6. Once this module has been loaded, there could be problems with all
+    7. Once this module has been loaded, there could be problems with all
        other plotting functions when using ``BokehBackend``, namely the
        figure won't show up in the output cell. If that is the case, we need
        to turn off  automatic updates on panning by setting
        ``update_event=False`` in the function call.
 
-    7. When ``BokehBackend`` is used:
+    8. When ``BokehBackend`` is used:
 
        * the user-defined theme won't be applied.
        * rendering of gradient lines is slow.
        * color bars might not update their ranges.
 
-    8. Once this module has been loaded and ``iplot`` has been executed, if
+    9. Once this module has been loaded and ``iplot`` has been executed, if
        the kernel of the notebook needs to be restarted, the safest procedure
        is the following:
 
@@ -1247,6 +1272,8 @@ def iplot(*args, show=True, **kwargs):
     ==========
 
     .. [#fn1] https://docs.bokeh.org/en/latest/docs/user_guide/styling.html#tick-label-formats
+    .. [#fn2] https://panel.holoviz.org/reference/panes/Matplotlib.html
+    .. [#fn3] https://panel.holoviz.org/reference/panes/Plotly.html
 
 
     See also
@@ -1270,7 +1297,7 @@ def create_widgets(params, **kwargs):
     params : dict
         A dictionary mapping the symbols to a parameter. The parameter can be:
 
-        1. an instance of `param.parameterized.Parameter`. Refer to [#fn2]_
+        1. an instance of `param.parameterized.Parameter`. Refer to [#fn5]_
            for a list of available parameters.
         2. a tuple of the form:
            `(default, min, max, N, tick_format, label, spacing)`
@@ -1331,7 +1358,7 @@ def create_widgets(params, **kwargs):
     References
     ==========
 
-    .. [#fn2] https://panel.holoviz.org/user_guide/Param.html
+    .. [#fn5] https://panel.holoviz.org/user_guide/Param.html
 
 
     See also
